<?php

/**
 * @file
 * This file provides administration form for the module.
 */

/**
 * Implements hook_form().
 */
function smartlook_tracking_admin_form($form, $form_state) {
  $form['general'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('General settings'),
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE,
  );

  $form['general']['smartlook_tracking_account'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Smartlook ID'),
    '#description'   => t('This ID is unique to each site you want to track separately. To get a Smartlook ID, <a href=":link">register your site with Smartlook</a>.', array(
      ':link' => 'https://www.smartlook.com',
    )),
    '#maxlength'     => 40,
    '#size'          => 40,
    '#default_value' => variable_get('smartlook_tracking_account', ''),
    '#required'      => TRUE,
  );

  // Visibility settings.
  $form['tracking_scope'] = array(
    '#type'  => 'vertical_tabs',
    '#title' => t('Advanced settings'),
  );

  $form['tracking_scope']['page_visibility_settings'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Pages'),
    '#collapsible' => FALSE,
    '#collapsed'   => FALSE,
  );

  $description = t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", array(
    '%blog'          => 'blog',
    '%blog-wildcard' => 'blog/*',
    '%front'         => '<front>'
  ));

  $form['tracking_scope']['page_visibility_settings']['smartlook_tracking_request_path_mode'] = array(
    '#type'          => 'radios',
    '#title'         => t('Add tracking to specific pages'),
    '#options'       => array(
      t('Every page except the listed pages'),
      t('The listed pages only'),
    ),
    '#default_value' => variable_get('smartlook_tracking_request_path_mode', 0),
  );

  $form['tracking_scope']['page_visibility_settings']['smartlook_tracking_request_path_pages'] = array(
    '#type'          => 'textarea',
    '#title'         => t('Pages'),
    '#title_display' => 'invisible',
    '#default_value' => variable_get('smartlook_tracking_request_path_pages', ''),
    '#description'   => $description,
    '#rows'          => 10,
  );

  $form['#attached']['js'][] = drupal_get_path('module', 'smartlook_tracking') . '/assets/js/smartlook_tracking.admin.js';

  return system_settings_form($form);
}

/**
 * Validates form.
 */
function smartlook_tracking_admin_form_validate($form, &$form_state) {
  $values = &$form_state['values'];

  $values['smartlook_tracking_account'] = trim($values['smartlook_tracking_account']);
  $values['smartlook_tracking_account'] = check_plain($values['smartlook_tracking_account']);

  $values['smartlook_tracking_request_path_mode'] = trim($values['smartlook_tracking_request_path_mode']);
  $values['smartlook_tracking_request_path_mode'] = check_plain($values['smartlook_tracking_request_path_mode']);

  $values['smartlook_tracking_request_path_pages'] = check_plain($values['smartlook_tracking_request_path_pages']);

  if (strlen($values['smartlook_tracking_account']) != 40) {
    form_set_error('smartlook_tracking_account', t('A valid Smartlook ID must be 40 characters long.'));
  }
}
